@@ -1,8 +1,6 @@
 # -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
-from django.db import models, migrations
-import raster.fields
+from django.contrib.gis.db import models
+from django.db import migrations
 
 
 class Migration(migrations.Migration):
@@ -31,9 +29,9 @@ class Migration(migrations.Migration):
             name='RasterTile',
             fields=[
                 ('rid', models.AutoField(serialize=False, primary_key=True)),
-                ('rast', raster.fields.RasterField(null=True, blank=True)),
+                ('rast', models.RasterField(null=True, blank=True)),
                 ('filename', models.TextField(null=True, blank=True)),
-                ('rasterlayer', models.ForeignKey(blank=True, to='raster.RasterLayer', null=True)),
+                ('rasterlayer', models.ForeignKey(blank=True, to='raster.RasterLayer', null=True, on_delete=models.CASCADE)),
             ],
             options={
             },
