@@ -1,7 +1,5 @@
 # -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
-from django.db import models, migrations
+from django.db import migrations, models
 
 
 class Migration(migrations.Migration):
@@ -24,7 +22,7 @@ class Migration(migrations.Migration):
                 ('skewx', models.FloatField(null=True, blank=True)),
                 ('skewy', models.FloatField(null=True, blank=True)),
                 ('numbands', models.IntegerField(null=True, blank=True)),
-                ('rasterlayer', models.OneToOneField(to='raster.RasterLayer')),
+                ('rasterlayer', models.OneToOneField(to='raster.RasterLayer', on_delete=models.CASCADE)),
             ],
             options={
             },
