@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
-from __future__ import unicode_literals
+from django.db import migrations
 
-from django.db import models, migrations
 
 class Migration(migrations.Migration):
 
